Index: pkg/custom_element/test/analyzer_test.dart |
diff --git a/samples/tests/samples/standalone/time_test.dart b/pkg/custom_element/test/analyzer_test.dart |
similarity index 61% |
copy from samples/tests/samples/standalone/time_test.dart |
copy to pkg/custom_element/test/analyzer_test.dart |
index 32a8726ccaba707e59d14c9eb5589b446682c6d3..1ac251bd58449c2510ebab6d5a33948b91939785 100644 |
--- a/samples/tests/samples/standalone/time_test.dart |
+++ b/pkg/custom_element/test/analyzer_test.dart |
@@ -2,13 +2,12 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-import '../../../time/time_server.dart' as time; |
+library custom_element.test.analyzer_test; |
+ |
+import 'package:custom_element/custom_element.dart'; |
// @static-clean |
/** |
* This test exists to ensure that the time sample compiles without errors. |
*/ |
void main() { |
- |
} |
@@ -2,13 +2,12 @@ |
// @static-clean |
-/** |
- * This test exists to ensure that the time sample compiles without errors. |
- */ |
+// This test ensures CustomElement compiles without errors. |
void main() { |